@@ -32,25 +32,25 @@ namespace native {
 struct MemoryHighWatermark {
     std::atomic<size_t> bytes_{0};
     std::atomic<size_t> high_{0};
-    void print( std::ostream& out ) const { out << eckit::Bytes( double( bytes_ ) ); }
-    friend std::ostream& operator<<( std::ostream& out, const MemoryHighWatermark& v ) {
-        v.print( out );
+    void print(std::ostream& out) const { out << eckit::Bytes(double(bytes_)); }
+    friend std::ostream& operator<<(std::ostream& out, const MemoryHighWatermark& v) {
+        v.print(out);
         return out;
     }
-    MemoryHighWatermark& operator+=( const size_t& bytes ) {
+    MemoryHighWatermark& operator+=(const size_t& bytes) {
         bytes_ += bytes;
         update_maximum();
-        if ( atlas::Library::instance().traceMemory() ) {
-            Log::trace() << "Memory: " << eckit::Bytes( double( bytes_ ) ) << "\t( +" << eckit::Bytes( double( bytes ) )
-                         << " \t| high watermark " << eckit::Bytes( double( high_ ) ) << "\t)" << std::endl;
+        if (atlas::Library::instance().traceMemory()) {
+            Log::trace() << "Memory: " << eckit::Bytes(double(bytes_)) << "\t( +" << eckit::Bytes(double(bytes))
+                         << " \t| high watermark " << eckit::Bytes(double(high_)) << "\t)" << std::endl;
         }
         return *this;
     }
-    MemoryHighWatermark& operator-=( const size_t& bytes ) {
+    MemoryHighWatermark& operator-=(const size_t& bytes) {
         bytes_ -= bytes;
-        if ( atlas::Library::instance().traceMemory() ) {
-            Log::trace() << "Memory: " << eckit::Bytes( double( bytes_ ) ) << "\t( -" << eckit::Bytes( double( bytes ) )
-                         << " \t| high watermark " << eckit::Bytes( double( high_ ) ) << "\t)" << std::endl;
+        if (atlas::Library::instance().traceMemory()) {
+            Log::trace() << "Memory: " << eckit::Bytes(double(bytes_)) << "\t( -" << eckit::Bytes(double(bytes))
+                         << " \t| high watermark " << eckit::Bytes(double(high_)) << "\t)" << std::endl;
         }
         return *this;
     }
@@ -59,7 +59,7 @@ private:
     MemoryHighWatermark() = default;
     void update_maximum() noexcept {
         size_t prev_value = high_;
-        while ( prev_value < bytes_ && !high_.compare_exchange_weak( prev_value, bytes_ ) ) {
+        while (prev_value < bytes_ && !high_.compare_exchange_weak(prev_value, bytes_)) {
         }
     }
 
@@ -72,33 +72,31 @@ public:
 
 template <typename Value>
 static constexpr Value invalid_value() {
-    return std::numeric_limits<Value>::has_signaling_NaN
-               ? std::numeric_limits<Value>::signaling_NaN()
-               : std::numeric_limits<Value>::has_quiet_NaN
-                     ? std::numeric_limits<Value>::quiet_NaN()
-                     : std::numeric_limits<Value>::has_infinity ? std::numeric_limits<Value>::infinity()
-                                                                : std::numeric_limits<Value>::max();
+    return std::numeric_limits<Value>::has_signaling_NaN ? std::numeric_limits<Value>::signaling_NaN()
+           : std::numeric_limits<Value>::has_quiet_NaN   ? std::numeric_limits<Value>::quiet_NaN()
+           : std::numeric_limits<Value>::has_infinity    ? std::numeric_limits<Value>::infinity()
+                                                         : std::numeric_limits<Value>::max();
 }
 
 #if ATLAS_INIT_SNAN
 template <typename Value>
-void initialise( Value array[], size_t size ) {
-    std::fill_n( array, size, invalid_value<Value>() );
+void initialise(Value array[], size_t size) {
+    std::fill_n(array, size, invalid_value<Value>());
 }
 #else
 template <typename Value>
-void initialise( Value[], size_t ) {}
+void initialise(Value[], size_t) {}
 #endif
 
 template <typename Value>
 class DataStore : public ArrayDataStore {
 public:
-    DataStore( size_t size ) : size_( size ) {
-        alloc_aligned( data_store_, size_ );
-        initialise( data_store_, size_ );
+    DataStore(size_t size): size_(size) {
+        alloc_aligned(data_store_, size_);
+        initialise(data_store_, size_);
     }
 
-    virtual ~DataStore() override { free_aligned( data_store_ ); }
+    virtual ~DataStore() override { free_aligned(data_store_); }
 
     virtual void updateDevice() const override {}
 
@@ -116,28 +114,28 @@ public:
 
     virtual void reactivateHostWriteViews() const override {}
 
-    virtual void* voidDataStore() override { return static_cast<void*>( data_store_ ); }
+    virtual void* voidDataStore() override { return static_cast<void*>(data_store_); }
 
-    virtual void* voidHostData() override { return static_cast<void*>( data_store_ ); }
+    virtual void* voidHostData() override { return static_cast<void*>(data_store_); }
 
-    virtual void* voidDeviceData() override { return static_cast<void*>( data_store_ ); }
+    virtual void* voidDeviceData() override { return static_cast<void*>(data_store_); }
 
 private:
-    [[noreturn]] void throw_AllocationFailed( size_t bytes, const eckit::CodeLocation& loc ) {
+    [[noreturn]] void throw_AllocationFailed(size_t bytes, const eckit::CodeLocation& loc) {
         std::ostringstream ss;
-        ss << "AllocationFailed: Could not allocate " << eckit::Bytes( bytes );
-        throw_Exception( ss.str(), loc );
+        ss << "AllocationFailed: Could not allocate " << eckit::Bytes(bytes);
+        throw_Exception(ss.str(), loc);
     }
 
-    void alloc_aligned( Value*& ptr, size_t n ) {
-        if ( n > 0 ) {
-            const size_t alignment = 64 * sizeof( Value );
-            size_t bytes           = sizeof( Value ) * n;
+    void alloc_aligned(Value*& ptr, size_t n) {
+        if (n > 0) {
+            const size_t alignment = 64 * sizeof(Value);
+            size_t bytes           = sizeof(Value) * n;
             MemoryHighWatermark::instance() += bytes;
 
-            int err = posix_memalign( (void**)&ptr, alignment, bytes );
-            if ( err ) {
-                throw_AllocationFailed( bytes, Here() );
+            int err = posix_memalign((void**)&ptr, alignment, bytes);
+            if (err) {
+                throw_AllocationFailed(bytes, Here());
             }
         }
         else {
@@ -145,15 +143,15 @@ private:
         }
     }
 
-    void free_aligned( Value*& ptr ) {
-        if ( size_ ) {
-            free( ptr );
+    void free_aligned(Value*& ptr) {
+        if (size_) {
+            free(ptr);
             ptr = nullptr;
             MemoryHighWatermark::instance() -= footprint();
         }
     }
 
-    size_t footprint() const { return sizeof( Value ) * size_; }
+    size_t footprint() const { return sizeof(Value) * size_; }
 
     Value* data_store_;
     size_t size_;
@@ -164,7 +162,7 @@ private:
 template <typename Value>
 class WrappedDataStore : public ArrayDataStore {
 public:
-    WrappedDataStore( Value* data_store ) : data_store_( data_store ) {}
+    WrappedDataStore(Value* data_store): data_store_(data_store) {}
 
     virtual void updateHost() const override {}
 
@@ -182,11 +180,11 @@ public:
 
     virtual void reactivateHostWriteViews() const override {}
 
-    virtual void* voidDataStore() override { return static_cast<void*>( data_store_ ); }
+    virtual void* voidDataStore() override { return static_cast<void*>(data_store_); }
 
-    virtual void* voidHostData() override { return static_cast<void*>( data_store_ ); }
+    virtual void* voidHostData() override { return static_cast<void*>(data_store_); }
 
-    virtual void* voidDeviceData() override { return static_cast<void*>( data_store_ ); }
+    virtual void* voidDeviceData() override { return static_cast<void*>(data_store_); }
 
 private:
     Value* data_store_;
