@@ -44,138 +44,138 @@ using Topology = atlas::mesh::Nodes::Topology;
 namespace atlas {
 namespace meshgenerator {
 
-RegularMeshGenerator::RegularMeshGenerator( const eckit::Parametrisation& p ) {
+RegularMeshGenerator::RegularMeshGenerator(const eckit::Parametrisation& p) {
     configure_defaults();
 
     // options copied from Structured MeshGenerator
     size_t nb_parts;
-    if ( p.get( "nb_parts", nb_parts ) ) {
-        options.set( "nb_parts", nb_parts );
+    if (p.get("nb_parts", nb_parts)) {
+        options.set("nb_parts", nb_parts);
     }
 
     size_t part;
-    if ( p.get( "part", part ) ) {
-        options.set( "part", part );
+    if (p.get("part", part)) {
+        options.set("part", part);
     }
 
     std::string partitioner;
-    if ( p.get( "partitioner", partitioner ) ) {
-        if ( not grid::Partitioner::exists( partitioner ) ) {
+    if (p.get("partitioner", partitioner)) {
+        if (not grid::Partitioner::exists(partitioner)) {
             Log::warning() << "Atlas does not have support for partitioner " << partitioner << ". "
                            << "Defaulting to use partitioner EqualRegions" << std::endl;
             partitioner = "equal_regions";
         }
-        options.set( "partitioner", partitioner );
+        options.set("partitioner", partitioner);
     }
 
     // options specifically for this MeshGenerator
     bool periodic_x;
-    if ( p.get( "periodic_x", periodic_x ) ) {
-        options.set( "periodic_x", periodic_x );
+    if (p.get("periodic_x", periodic_x)) {
+        options.set("periodic_x", periodic_x);
     }
 
     bool periodic_y;
-    if ( p.get( "periodic_y", periodic_y ) ) {
-        options.set( "periodic_y", periodic_y );
+    if (p.get("periodic_y", periodic_y)) {
+        options.set("periodic_y", periodic_y);
     }
 
     bool biperiodic;
-    if ( p.get( "biperiodic", biperiodic ) ) {
-        options.set( "periodic_x", biperiodic );
-        options.set( "periodic_y", biperiodic );
+    if (p.get("biperiodic", biperiodic)) {
+        options.set("periodic_x", biperiodic);
+        options.set("periodic_y", biperiodic);
     }
 }
 
 void RegularMeshGenerator::configure_defaults() {
     // This option sets number of parts the mesh will be split in
-    options.set( "nb_parts", mpi::size() );
+    options.set("nb_parts", mpi::size());
 
     // This option sets the part that will be generated
-    options.set( "part", mpi::rank() );
+    options.set("part", mpi::rank());
 
     // This options sets the default partitioner
     std::string partitioner;
-    if ( grid::Partitioner::exists( "trans" ) && mpi::size() > 1 ) {
+    if (grid::Partitioner::exists("trans") && mpi::size() > 1) {
         partitioner = "trans";
     }
     else {
         partitioner = "checkerboard";
     }
-    options.set<std::string>( "partitioner", partitioner );
+    options.set<std::string>("partitioner", partitioner);
 
     // Options for for periodic grids
-    options.set<bool>( "periodic_x", false );
-    options.set<bool>( "periodic_y", false );
+    options.set<bool>("periodic_x", false);
+    options.set<bool>("periodic_y", false);
 }
 
-void RegularMeshGenerator::generate( const Grid& grid, Mesh& mesh ) const {
-    ATLAS_ASSERT( !mesh.generated() );
+void RegularMeshGenerator::generate(const Grid& grid, Mesh& mesh) const {
+    ATLAS_ASSERT(!mesh.generated());
 
-    const RegularGrid rg = RegularGrid( grid );
-    if ( !rg ) {
-        throw_Exception( "RegularMeshGenerator can only work with a Regular grid", Here() );
+    const RegularGrid rg = RegularGrid(grid);
+    if (!rg) {
+        throw_Exception("RegularMeshGenerator can only work with a Regular grid", Here());
     }
 
-    size_t nb_parts = options.get<size_t>( "nb_parts" );
+    size_t nb_parts = options.get<size_t>("nb_parts");
 
     std::string partitioner_type = "checkerboard";
-    options.get( "checkerboard", partitioner_type );
+    options.get("checkerboard", partitioner_type);
 
     // if ( rg->nlat()%2 == 1 ) partitioner_factory = "equal_regions"; // Odd
     // number of latitudes
     // if ( nb_parts == 1 || eckit::mpi::size() == 1 ) partitioner_factory =
     // "equal_regions"; // Only one part --> Trans is slower
 
-    grid::Partitioner partitioner( partitioner_type, nb_parts );
-    grid::Distribution distribution( partitioner.partition( grid ) );
-    generate( grid, distribution, mesh );
+    grid::Partitioner partitioner(partitioner_type, nb_parts);
+    grid::Distribution distribution(partitioner.partition(grid));
+    generate(grid, distribution, mesh);
 }
 
-void RegularMeshGenerator::hash( eckit::Hash& h ) const {
-    h.add( "RegularMeshGenerator" );
-    options.hash( h );
+void RegularMeshGenerator::hash(eckit::Hash& h) const {
+    h.add("RegularMeshGenerator");
+    options.hash(h);
 }
 
-void RegularMeshGenerator::generate( const Grid& grid, const grid::Distribution& distribution, Mesh& mesh ) const {
-    const auto rg = RegularGrid( grid );
-    if ( !rg ) {
-        throw_Exception( "Grid could not be cast to a Regular", Here() );
+void RegularMeshGenerator::generate(const Grid& grid, const grid::Distribution& distribution, Mesh& mesh) const {
+    const auto rg = RegularGrid(grid);
+    if (!rg) {
+        throw_Exception("Grid could not be cast to a Regular", Here());
     }
 
-    ATLAS_ASSERT( !mesh.generated() );
+    ATLAS_ASSERT(!mesh.generated());
 
-    if ( grid.size() != static_cast<idx_t>( distribution.size() ) ) {
+    if (grid.size() != static_cast<idx_t>(distribution.size())) {
         std::stringstream msg;
         msg << "Number of points in grid (" << grid.size()
             << ") different from "
                "number of points in grid distribution ("
             << distribution.size() << ")";
-        throw_AssertionFailed( msg.str(), Here() );
+        throw_AssertionFailed(msg.str(), Here());
     }
 
     // clone some grid properties
-    setGrid( mesh, rg, distribution );
+    setGrid(mesh, rg, distribution);
 
-    generate_mesh( rg, distribution, mesh );
+    generate_mesh(rg, distribution, mesh);
 }
 
-void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Distribution& distribution,
-                                          // const Region& region,
-                                          Mesh& mesh ) const {
-    int mypart = options.get<size_t>( "part" );
-    int nparts = options.get<size_t>( "nb_parts" );
+void RegularMeshGenerator::generate_mesh(const RegularGrid& rg, const grid::Distribution& distribution,
+                                         // const Region& region,
+                                         Mesh& mesh) const {
+    int mypart = options.get<size_t>("part");
+    int nparts = options.get<size_t>("nb_parts");
     int nx     = rg.nx();
     int ny     = rg.ny();
 
-    bool periodic_x = options.get<bool>( "periodic_x" ) or rg.periodic();
-    bool periodic_y = options.get<bool>( "periodic_y" );
+    bool periodic_x = options.get<bool>("periodic_x") or rg.periodic();
+    bool periodic_y = options.get<bool>("periodic_y");
 
     Log::debug() << Here() << " periodic_x = " << periodic_x << std::endl;
     Log::debug() << Here() << " periodic_y = " << periodic_y << std::endl;
 
 // for asynchronous output
 #if DEBUG_OUTPUT
-    sleep( mypart );
+    sleep(mypart);
 #endif
 
     // this function should do the following:
@@ -210,8 +210,8 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
     int ncells;
 
     // vector of local indices: necessary for remote indices of ghost nodes
-    std::vector<int> local_idx( rg.size(), -1 );
-    std::vector<int> current_idx( nparts, 0 );  // index counter for each proc
+    std::vector<int> local_idx(rg.size(), -1);
+    std::vector<int> current_idx(nparts, 0);  // index counter for each proc
 
     // determine rectangle (ix_min:ix_max) x (iy_min:iy_max) surrounding the nodes
     // on this processor
@@ -228,17 +228,17 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
     nnodes_nonghost = 0;
 
     ii_glb = 0;
-    for ( iy = 0; iy < ny; iy++ ) {
-        for ( ix = 0; ix < nx; ix++ ) {
-            local_idx[ii_glb] = current_idx[distribution.partition( ii_glb )]++;  // store local index on
-                                                                                  // the local proc of
-                                                                                  // this point
-            if ( distribution.partition( ii_glb ) == mypart ) {
+    for (iy = 0; iy < ny; iy++) {
+        for (ix = 0; ix < nx; ix++) {
+            local_idx[ii_glb] = current_idx[distribution.partition(ii_glb)]++;  // store local index on
+                                                                                // the local proc of
+                                                                                // this point
+            if (distribution.partition(ii_glb) == mypart) {
                 ++nnodes_nonghost;  // non-ghost node: belongs to this part
-                ix_min = std::min( ix_min, ix );
-                ix_max = std::max( ix_max, ix );
-                iy_min = std::min( iy_min, iy );
-                iy_max = std::max( iy_max, iy );
+                ix_min = std::min(ix_min, ix);
+                ix_max = std::max(ix_max, ix);
+                iy_min = std::min(iy_min, iy);
+                iy_max = std::max(iy_max, iy);
             }
             ++ii_glb;  // global index
         }
@@ -261,36 +261,36 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
     nnodes_SR = nxl * nyl;
 
     // partitions and local indices in SR
-    std::vector<int> parts_SR( nnodes_SR, -1 );
-    std::vector<int> local_idx_SR( nnodes_SR, -1 );
-    std::vector<bool> is_ghost_SR( nnodes_SR, true );
+    std::vector<int> parts_SR(nnodes_SR, -1);
+    std::vector<int> local_idx_SR(nnodes_SR, -1);
+    std::vector<bool> is_ghost_SR(nnodes_SR, true);
     ii = 0;  // index inside SR
-    for ( iy = 0; iy < nyl; iy++ ) {
-        iy_glb = ( iy_min + iy );  // global y-index
-        for ( ix = 0; ix < nxl; ix++ ) {
-            ix_glb          = ( ix_min + ix );  // global x-index
-            is_ghost_SR[ii] = !( ( parts_SR[ii] == mypart ) && ix < nxl - 1 && iy < nyl - 1 );
-            if ( ix_glb < nx && iy_glb < ny ) {
+    for (iy = 0; iy < nyl; iy++) {
+        iy_glb = (iy_min + iy);  // global y-index
+        for (ix = 0; ix < nxl; ix++) {
+            ix_glb          = (ix_min + ix);  // global x-index
+            is_ghost_SR[ii] = !((parts_SR[ii] == mypart) && ix < nxl - 1 && iy < nyl - 1);
+            if (ix_glb < nx && iy_glb < ny) {
                 ii_glb           = (iy_glb)*nx + ix_glb;  // global index
-                parts_SR[ii]     = distribution.partition( ii_glb );
+                parts_SR[ii]     = distribution.partition(ii_glb);
                 local_idx_SR[ii] = local_idx[ii_glb];
-                is_ghost_SR[ii]  = !( ( parts_SR[ii] == mypart ) && ix < nxl - 1 && iy < nyl - 1 );
+                is_ghost_SR[ii]  = !((parts_SR[ii] == mypart) && ix < nxl - 1 && iy < nyl - 1);
             }
-            else if ( ix_glb == nx && iy_glb < ny ) {
+            else if (ix_glb == nx && iy_glb < ny) {
                 // take properties from the point to the left
-                parts_SR[ii]     = distribution.partition( iy_glb * nx + ix_glb - 1 );
+                parts_SR[ii]     = distribution.partition(iy_glb * nx + ix_glb - 1);
                 local_idx_SR[ii] = -1;
                 is_ghost_SR[ii]  = true;
             }
-            else if ( iy_glb == ny && ix_glb < nx ) {
+            else if (iy_glb == ny && ix_glb < nx) {
                 // take properties from the point below
-                parts_SR[ii]     = distribution.partition( ( iy_glb - 1 ) * nx + ix_glb );
+                parts_SR[ii]     = distribution.partition((iy_glb - 1) * nx + ix_glb);
                 local_idx_SR[ii] = -1;
                 is_ghost_SR[ii]  = true;
             }
             else {
                 // take properties from the point belowleft
-                parts_SR[ii]     = distribution.partition( ( iy_glb - 1 ) * nx + ix_glb - 1 );
+                parts_SR[ii]     = distribution.partition((iy_glb - 1) * nx + ix_glb - 1);
                 local_idx_SR[ii] = -1;
                 is_ghost_SR[ii]  = true;
             }
@@ -301,54 +301,54 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
 #if DEBUG_OUTPUT_DETAIL
     std::cout << "[" << mypart << "] : "
               << "parts_SR = ";
-    for ( ii = 0; ii < nnodes_SR; ii++ )
+    for (ii = 0; ii < nnodes_SR; ii++)
         std::cout << parts_SR[ii] << ",";
     std::cout << std::endl;
     std::cout << "[" << mypart << "] : "
               << "local_idx_SR = ";
-    for ( ii = 0; ii < nnodes_SR; ii++ )
+    for (ii = 0; ii < nnodes_SR; ii++)
         std::cout << local_idx_SR[ii] << ",";
     std::cout << std::endl;
     std::cout << "[" << mypart << "] : "
               << "is_ghost_SR = ";
-    for ( ii = 0; ii < nnodes_SR; ii++ )
+    for (ii = 0; ii < nnodes_SR; ii++)
         std::cout << is_ghost_SR[ii] << ",";
     std::cout << std::endl;
 #endif
 
     // vectors marking nodes that are necessary for this proc's cells
-    std::vector<bool> is_node_SR( nnodes_SR, false );
+    std::vector<bool> is_node_SR(nnodes_SR, false);
 
     // determine number of cells and number of nodes
     nnodes = 0;
     ncells = 0;
-    for ( iy = 0; iy < nyl - 1; iy++ ) {      // don't loop into ghost/periodicity row
-        for ( ix = 0; ix < nxl - 1; ix++ ) {  // don't loop into ghost/periodicity column
+    for (iy = 0; iy < nyl - 1; iy++) {      // don't loop into ghost/periodicity row
+        for (ix = 0; ix < nxl - 1; ix++) {  // don't loop into ghost/periodicity column
             ii = iy * nxl + ix;
-            if ( !is_ghost_SR[ii] ) {
+            if (!is_ghost_SR[ii]) {
                 // mark this node as being used
-                if ( !is_node_SR[ii] ) {
+                if (!is_node_SR[ii]) {
                     ++nnodes;
                     is_node_SR[ii] = true;
                 }
                 // check if this node is the lowerleft corner of a new cell
-                if ( ( ix_min + ix < nx - 1 || periodic_x ) && ( iy_min + iy < ny - 1 || periodic_y ) ) {
+                if ((ix_min + ix < nx - 1 || periodic_x) && (iy_min + iy < ny - 1 || periodic_y)) {
                     ++ncells;
                     // mark lowerright corner
                     ii = iy * nxl + ix + 1;
-                    if ( !is_node_SR[ii] ) {
+                    if (!is_node_SR[ii]) {
                         ++nnodes;
                         is_node_SR[ii] = true;
                     }
                     // mark upperleft corner
-                    ii = ( iy + 1 ) * nxl + ix;
-                    if ( !is_node_SR[ii] ) {
+                    ii = (iy + 1) * nxl + ix;
+                    if (!is_node_SR[ii]) {
                         ++nnodes;
                         is_node_SR[ii] = true;
                     }
                     // mark upperright corner
-                    ii = ( iy + 1 ) * nxl + ix + 1;
-                    if ( !is_node_SR[ii] ) {
+                    ii = (iy + 1) * nxl + ix + 1;
+                    if (!is_node_SR[ii]) {
                         ++nnodes;
                         is_node_SR[ii] = true;
                     }
@@ -356,17 +356,17 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
                 // periodic points are always needed, even if they don't belong to a
                 // cell
                 ii = iy * nxl + ix + 1;
-                if ( periodic_x && ix_min + ix == nx - 1 && !is_node_SR[ii] ) {
+                if (periodic_x && ix_min + ix == nx - 1 && !is_node_SR[ii]) {
                     ++nnodes;
                     is_node_SR[ii] = true;
                 }
-                ii = ( iy + 1 ) * nxl + ix;
-                if ( periodic_y && iy_min + iy == ny - 1 && !is_node_SR[ii] ) {
+                ii = (iy + 1) * nxl + ix;
+                if (periodic_y && iy_min + iy == ny - 1 && !is_node_SR[ii]) {
                     ++nnodes;
                     is_node_SR[ii] = true;
                 }
-                ii = ( iy + 1 ) * nxl + ix + 1;
-                if ( periodic_x && periodic_y && ix_min + ix == nx - 1 && iy_min + iy == ny - 1 && !is_node_SR[ii] ) {
+                ii = (iy + 1) * nxl + ix + 1;
+                if (periodic_x && periodic_y && ix_min + ix == nx - 1 && iy_min + iy == ny - 1 && !is_node_SR[ii]) {
                     ++nnodes;
                     is_node_SR[ii] = true;
                 }
@@ -379,26 +379,26 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
               << "nnodes = " << nnodes << std::endl;
     std::cout << "[" << mypart << "] : "
               << "is_node_SR = ";
-    for ( ii = 0; ii < nnodes_SR; ii++ )
+    for (ii = 0; ii < nnodes_SR; ii++)
         std::cout << is_node_SR[ii] << ",";
     std::cout << std::endl;
 #endif
 
     // define nodes and associated properties
-    mesh.nodes().resize( nnodes );
+    mesh.nodes().resize(nnodes);
     mesh::Nodes& nodes = mesh.nodes();
-    auto xy            = array::make_view<double, 2>( nodes.xy() );
-    auto lonlat        = array::make_view<double, 2>( nodes.lonlat() );
-    auto glb_idx       = array::make_view<gidx_t, 1>( nodes.global_index() );
-    auto remote_idx    = array::make_indexview<idx_t, 1>( nodes.remote_index() );
-    auto part          = array::make_view<int, 1>( nodes.partition() );
-    auto ghost         = array::make_view<int, 1>( nodes.ghost() );
-    auto flags         = array::make_view<int, 1>( nodes.flags() );
+    auto xy            = array::make_view<double, 2>(nodes.xy());
+    auto lonlat        = array::make_view<double, 2>(nodes.lonlat());
+    auto glb_idx       = array::make_view<gidx_t, 1>(nodes.global_index());
+    auto remote_idx    = array::make_indexview<idx_t, 1>(nodes.remote_index());
+    auto part          = array::make_view<int, 1>(nodes.partition());
+    auto ghost         = array::make_view<int, 1>(nodes.ghost());
+    auto flags         = array::make_view<int, 1>(nodes.flags());
 
     // define cells and associated properties
-    mesh.cells().add( new mesh::temporary::Quadrilateral(), ncells );
-    int quad_begin                                        = mesh.cells().elements( 0 ).begin();
-    auto cells_part                                       = array::make_view<int, 1>( mesh.cells().partition() );
+    mesh.cells().add(new mesh::temporary::Quadrilateral(), ncells);
+    int quad_begin                                        = mesh.cells().elements(0).begin();
+    auto cells_part                                       = array::make_view<int, 1>(mesh.cells().partition());
     mesh::HybridElements::Connectivity& node_connectivity = mesh.cells().node_connectivity();
 
     idx_t quad_nodes[4];
@@ -407,15 +407,15 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
 
     // global indices for periodicity points
     inode = nx * ny;
-    std::vector<int> glb_idx_px( ny + 1, -1 );
-    std::vector<int> glb_idx_py( nx + 1, -1 );
-    if ( periodic_x ) {
-        for ( iy = 0; iy < ny + ( periodic_y ? 1 : 0 ); iy++ ) {
+    std::vector<int> glb_idx_px(ny + 1, -1);
+    std::vector<int> glb_idx_py(nx + 1, -1);
+    if (periodic_x) {
+        for (iy = 0; iy < ny + (periodic_y ? 1 : 0); iy++) {
             glb_idx_px[iy] = inode++;
         }
     }
-    if ( periodic_y ) {
-        for ( ix = 0; ix < nx; ix++ ) {
+    if (periodic_y) {
+        for (ix = 0; ix < nx; ix++) {
             glb_idx_py[ix] = inode++;
         }
     }
@@ -424,26 +424,26 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
     ii             = 0;
     inode_nonghost = 0;
     inode_ghost    = nnodes_nonghost;  // ghost nodes start counting after nonghost nodes
-    for ( iy = 0; iy < nyl; iy++ ) {
-        for ( ix = 0; ix < nxl; ix++ ) {
+    for (iy = 0; iy < nyl; iy++) {
+        for (ix = 0; ix < nxl; ix++) {
             // node properties
-            if ( is_node_SR[ii] ) {
+            if (is_node_SR[ii]) {
                 // set node counter
-                if ( is_ghost_SR[ii] ) {
+                if (is_ghost_SR[ii]) {
                     inode = inode_ghost++;
                 }
                 else {
                     inode = inode_nonghost++;
                 }
                 // global index
-                ix_glb = ( ix_min + ix );  // don't take modulus here: periodicity points
-                                           // have their own global index.
-                iy_glb = ( iy_min + iy );
-                if ( ix_glb < nx && iy_glb < ny ) {
+                ix_glb = (ix_min + ix);  // don't take modulus here: periodicity points
+                                         // have their own global index.
+                iy_glb = (iy_min + iy);
+                if (ix_glb < nx && iy_glb < ny) {
                     ii_glb = iy_glb * nx + ix_glb;  // no periodic point
                 }
                 else {
-                    if ( ix_glb == nx ) {
+                    if (ix_glb == nx) {
                         // periodicity point in x-direction
                         ii_glb = glb_idx_px[iy_glb];
                     }
@@ -452,12 +452,12 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
                         ii_glb = glb_idx_py[ix_glb];
                     }
                 }
-                glb_idx( inode ) = ii_glb + 1;  // starting from 1
+                glb_idx(inode) = ii_glb + 1;  // starting from 1
                 // grid coordinates
                 double _xy[2];
-                if ( iy_glb < ny ) {
+                if (iy_glb < ny) {
                     // normal calculation
-                    rg.xy( ix_glb, iy_glb, _xy );
+                    rg.xy(ix_glb, iy_glb, _xy);
                 }
                 else {
                     // for periodic_y grids, iy_glb==ny lies outside the range of
@@ -465,33 +465,33 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
                     // so we extrapolate from two other points -- this is okay for regular
                     // grids with uniform spacing.
                     double xy1[2], xy2[2];
-                    rg.xy( ix_glb, iy_glb - 1, xy1 );
-                    rg.xy( ix_glb, iy_glb - 2, xy2 );
+                    rg.xy(ix_glb, iy_glb - 1, xy1);
+                    rg.xy(ix_glb, iy_glb - 2, xy2);
                     _xy[0] = 2 * xy1[0] - xy2[0];
                     _xy[1] = 2 * xy1[1] - xy2[1];
                 }
-                xy( inode, LON ) = _xy[LON];
-                xy( inode, LAT ) = _xy[LAT];
+                xy(inode, LON) = _xy[LON];
+                xy(inode, LAT) = _xy[LAT];
 
                 // geographic coordinates by using projection
-                rg.projection().xy2lonlat( _xy );
-                lonlat( inode, LON ) = _xy[LON];
-                lonlat( inode, LAT ) = _xy[LAT];
+                rg.projection().xy2lonlat(_xy);
+                lonlat(inode, LON) = _xy[LON];
+                lonlat(inode, LAT) = _xy[LAT];
 
                 // part
-                part( inode ) = parts_SR[ii];
+                part(inode) = parts_SR[ii];
                 // ghost nodes
-                ghost( inode ) = is_ghost_SR[ii];
+                ghost(inode) = is_ghost_SR[ii];
                 // flags
-                Topology::reset( flags( inode ) );
-                if ( ghost( inode ) ) {
-                    Topology::set( flags( inode ), Topology::GHOST );
-                    remote_idx( inode ) = local_idx_SR[ii];
+                Topology::reset(flags(inode));
+                if (ghost(inode)) {
+                    Topology::set(flags(inode), Topology::GHOST);
+                    remote_idx(inode) = local_idx_SR[ii];
                     // change local index -- required for cells
                     local_idx_SR[ii] = inode;
                 }
                 else {
-                    remote_idx( inode ) = -1;
+                    remote_idx(inode) = -1;
                 }
 
 #if DEBUG_OUTPUT_DETAIL
@@ -502,8 +502,8 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
                           << "\tinode=" << inode << "; ix_glb=" << ix_glb << "; iy_glb=" << iy_glb
                           << "; glb_idx=" << ii_glb << std::endl;
                 std::cout << "[" << mypart << "] : "
-                          << "\tglon=" << lonlat( inode, 0 ) << "; glat=" << lonlat( inode, 1 )
-                          << "; glb_idx=" << glb_idx( inode ) << std::endl;
+                          << "\tglon=" << lonlat(inode, 0) << "; glat=" << lonlat(inode, 1)
+                          << "; glb_idx=" << glb_idx(inode) << std::endl;
 #endif
             }
             ++ii;
@@ -511,18 +511,18 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
     }
 
     // loop over nodes and define cells
-    for ( iy = 0; iy < nyl - 1; iy++ ) {      // don't loop into ghost/periodicity row
-        for ( ix = 0; ix < nxl - 1; ix++ ) {  // don't loop into ghost/periodicity column
+    for (iy = 0; iy < nyl - 1; iy++) {      // don't loop into ghost/periodicity row
+        for (ix = 0; ix < nxl - 1; ix++) {  // don't loop into ghost/periodicity column
             ii = iy * nxl + ix;
-            if ( !is_ghost_SR[ii] ) {
-                if ( ( ix_min + ix < nx - 1 || periodic_x ) && ( iy_min + iy < ny - 1 || periodic_y ) ) {
+            if (!is_ghost_SR[ii]) {
+                if ((ix_min + ix < nx - 1 || periodic_x) && (iy_min + iy < ny - 1 || periodic_y)) {
                     // define cell corners (local indices)
                     quad_nodes[0] = local_idx_SR[ii];
-                    quad_nodes[3] = local_idx_SR[iy * nxl + ix + 1];          // point to the right
-                    quad_nodes[2] = local_idx_SR[( iy + 1 ) * nxl + ix + 1];  // point above right
-                    quad_nodes[1] = local_idx_SR[( iy + 1 ) * nxl + ix];      // point above
-                    node_connectivity.set( jcell, quad_nodes );
-                    cells_part( jcell ) = mypart;
+                    quad_nodes[3] = local_idx_SR[iy * nxl + ix + 1];        // point to the right
+                    quad_nodes[2] = local_idx_SR[(iy + 1) * nxl + ix + 1];  // point above right
+                    quad_nodes[1] = local_idx_SR[(iy + 1) * nxl + ix];      // point above
+                    node_connectivity.set(jcell, quad_nodes);
+                    cells_part(jcell) = mypart;
 #if DEBUG_OUTPUT_DETAIL
                     std::cout << "[" << mypart << "] : "
                               << "New quad " << jcell << "\n\t";
@@ -537,28 +537,28 @@ void RegularMeshGenerator::generate_mesh( const RegularGrid& rg, const grid::Dis
 
 #if DEBUG_OUTPUT
     // list nodes
-    for ( inode = 0; inode < nnodes; inode++ ) {
+    for (inode = 0; inode < nnodes; inode++) {
         std::cout << "[" << mypart << "] : "
-                  << " node " << inode << ": ghost = " << ghost( inode ) << ", glb_idx = " << glb_idx( inode ) - 1
-                  << ", part = " << part( inode ) << ", lon = " << lonlat( inode, 0 )
-                  << ", lat = " << lonlat( inode, 1 ) << ", remote_idx = " << remote_idx( inode ) << std::endl;
+                  << " node " << inode << ": ghost = " << ghost(inode) << ", glb_idx = " << glb_idx(inode) - 1
+                  << ", part = " << part(inode) << ", lon = " << lonlat(inode, 0) << ", lat = " << lonlat(inode, 1)
+                  << ", remote_idx = " << remote_idx(inode) << std::endl;
     }
 
     int* cell_nodes;
-    for ( jcell = 0; jcell < ncells; jcell++ ) {
+    for (jcell = 0; jcell < ncells; jcell++) {
         std::cout << "[" << mypart << "] : "
-                  << " cell " << jcell << ": " << node_connectivity( jcell, 0 ) << "," << node_connectivity( jcell, 1 )
-                  << "," << node_connectivity( jcell, 2 ) << "," << node_connectivity( jcell, 3 ) << std::endl;
+                  << " cell " << jcell << ": " << node_connectivity(jcell, 0) << "," << node_connectivity(jcell, 1)
+                  << "," << node_connectivity(jcell, 2) << "," << node_connectivity(jcell, 3) << std::endl;
     }
 #endif
 
-    generateGlobalElementNumbering( mesh );
+    generateGlobalElementNumbering(mesh);
 
-    nodes.metadata().set( "parallel", true );
+    nodes.metadata().set("parallel", true);
 }
 
 namespace {
-static MeshGeneratorBuilder<RegularMeshGenerator> __RegularMeshGenerator( "regular" );
+static MeshGeneratorBuilder<RegularMeshGenerator> __RegularMeshGenerator("regular");
 }
 
 }  // namespace meshgenerator
