@@ -30,7 +30,7 @@ public:
     using const_reverse_iterator = std::list<size_t>::const_reverse_iterator;
 
 public:
-    void push_front( const CodeLocation&, const std::string& id = "" );
+    void push_front(const CodeLocation&, const std::string& id = "");
     void pop_front();
 
     const_iterator begin() const { return stack_.begin(); }
@@ -44,6 +44,15 @@ public:
 
     operator bool() const { return not stack_.empty(); }
 
+public:
+    CallStack() = default;
+    CallStack(const CallStack& other): stack_(other.stack_) {}
+    CallStack& operator=(const CallStack& other) {
+        stack_ = other.stack_;
+        hash_  = 0;
+        return *this;
+    }
+
 private:
     std::list<size_t> stack_;
     mutable size_t hash_{0};
